.. This helps define the TOC ordering for "about us" sections. Particularly
   useful for PDF output as this section is not linked from elsewhere.

.. Places global toc into the sidebar

:globalsidebartoc: True

.. _preface_menu:

.. include:: includes/big_toc_css.rst
.. include:: tune_toc.rst

=======================
Welcome to scikit-learn
=======================

|

.. toctree::
    :maxdepth: 2

    install
    faq
    support
    related_projects
    about
    testimonials/testimonials
    whats_new
    roadmap
    governance

|
